﻿using System;
using System.Collections.Generic;

namespace MPlayer.DotNet
{
    /// <summary>
    /// Contains constraits for modes
    /// </summary>
    public class MPlayerAudioMode
    {
        private readonly Dictionary<MPlayerAudioModeName, MPlayerModeCommand> _displayModes;

        public MPlayerAudioMode()
        {
            _displayModes = new Dictionary<MPlayerAudioModeName, MPlayerModeCommand>();
            var modes = new[]
            {
                new MPlayerModeCommand(MPlayerAudioModeName.Alsa, "alsa", new[] { PlatformID.Unix }),
                new MPlayerModeCommand(MPlayerAudioModeName.DirectSound, "dsound", new[] { PlatformID.Xbox, PlatformID.Win32NT, PlatformID.Win32Windows }),
                new MPlayerModeCommand(MPlayerAudioModeName.Win32, "win32", new[] { PlatformID.Win32NT, PlatformID.Win32Windows }),
            };

            foreach (var mode in modes)
            {
                _displayModes.Add(mode.AudioMode, mode);
            }

            switch (Environment.OSVersion.Platform)
            {
                case PlatformID.MacOSX:
                    _mode = MPlayerAudioModeName.Alsa;
                    break;
                case PlatformID.Unix:
                    _mode = MPlayerAudioModeName.Alsa;
                    break;
                default:
                    _mode = MPlayerAudioModeName.DirectSound;
                    break;
            }
        }

        private MPlayerAudioModeName _mode;

        public string ModeCommand
        {
            get { return _displayModes[_mode].Command; }
        }

        public MPlayerAudioModeName Mode
        {
            get { return _mode; }
            set
            {
                if (_displayModes[value].Platroms.Contains(Environment.OSVersion.Platform))
                    _mode = value;
            }
        }
    }

    /// <summary>
    /// Video output modes
    /// </summary>
    public enum MPlayerAudioModeName
    {
        Win32,
        DirectSound,
        Alsa
    } 
}
